@@ -2,7 +2,8 @@
 validation_passes = {
     'failing_noop': -1,
     'endorsement': 0,
-    'proposal': 1,
+    'endorsement_with_slot': 0,
+    'proposals': 1,
     'ballot': 1,
     'seed_nonce_revelation': 2,
     'double_endorsement_evidence': 2,
@@ -15,7 +16,8 @@ validation_passes = {
 }
 operation_tags = {
     'endorsement': 0,
-    'proposal': 5,
+    'endorsement_with_slot': 10,
+    'proposals': 5,
     'ballot': 6,
     'seed_nonce_revelation': 1,
     'double_endorsement_evidence': 2,
