@@ -7,7 +7,8 @@ import requests.exceptions
 from testcontainers.core.generic import DockerContainer  # type: ignore
 
 from pytezos.client import PyTezosClient
-from pytezos.sandbox.parameters import EDO
+from pytezos.operation.group import OperationGroup
+from pytezos.sandbox.parameters import FLORENCE
 
 # NOTE: Container object is a singleton which will be used in all tests inherited from class _SandboxedNodeTestCase
 # and stopped after all tests are completed.
@@ -17,13 +18,21 @@ node_fitness: int = 1
 
 
 class SandboxedNodeTestCase(unittest.TestCase):
+    """Perform tests with sanboxed node in Docker container."""
+
     IMAGE: str = 'bakingbad/sandboxed-node:v9.0-rc1-1'
+    "Docker image to use"
+
     PORT: Optional[int] = None
-    PROTOCOL: str = EDO
+    "Port to expose to host machine"
+
+    PROTOCOL: str = FLORENCE
+    "Hash of protocol to activate"
 
     @classmethod
     def setUpClass(cls) -> None:
-        global node_container
+        """Spin up sandboxed node container and activate protocol."""
+        global node_container  # pylint: disable=global-statement
         if not node_container:
             node_container = cls._create_node_container()
             node_container.start()
@@ -33,7 +42,8 @@ class SandboxedNodeTestCase(unittest.TestCase):
         cls.activate(cls.PROTOCOL, reset=True)
 
     @classmethod
-    def activate(cls, protocol_alias: str, reset: bool = False):
+    def activate(cls, protocol_alias: str, reset: bool = False) -> OperationGroup:
+        """Activate protocol."""
         return (
             cls.get_client()
             .using(key='dictator')
@@ -45,29 +55,24 @@ class SandboxedNodeTestCase(unittest.TestCase):
 
     @classmethod
     def get_node_url(cls) -> str:
-        container = cls.get_node_container()
+        """Get sandboxed node URL."""
+        container = cls._get_node_container()
         container_id = container.get_wrapped_container().id
         host = container.get_docker_client().bridge_ip(container_id)
         return f'http://{host}:8732'
 
     @classmethod
-    def get_node_container(cls) -> DockerContainer:
+    def _get_node_container(cls) -> DockerContainer:
         if node_container is None:
             raise RuntimeError('Sandboxed node container is not running')
         return node_container
 
     @classmethod
-    def get_client(cls):
+    def get_client(cls) -> PyTezosClient:
         return node_container_client.using(
             shell=cls.get_node_url(),
         )
 
-    @classmethod
-    def create_client(cls):
-        global node_container_client
-        node_container_client = PyTezosClient()
-        return cls.get_client()
-
     @classmethod
     def _create_node_container(cls) -> DockerContainer:
         container = DockerContainer(
@@ -88,9 +93,14 @@ class SandboxedNodeTestCase(unittest.TestCase):
                 sleep(0.1)
 
     @classmethod
-    def bake_block(cls, min_fee: int = 0):
+    def bake_block(cls, min_fee: int = 0) -> OperationGroup:
+        """Bake new block.
+
+        :param min_fee: minimum fee of operation to be included in block
+        """
         return cls.get_client().using(key='bootstrap1').bake_block(min_fee).fill().work().sign().inject()
 
     @property
     def client(self) -> PyTezosClient:
+        """PyTezos client to interact with sandboxed node."""
         return self.get_client().using(key='bootstrap2')
